@@ -9,6 +9,9 @@
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QLabel>
+#include <QUrl>
+
+#include "webpreview.h"
 
 CommentView::CommentView(RedditSession* ses, QWidget *parent) :
     QMainWindow(parent),
@@ -20,9 +23,10 @@ CommentView::CommentView(RedditSession* ses, QWidget *parent) :
     connect(m_ses, SIGNAL(commentsAvailable()), this, SLOT(populate()));
     menuBar()->addAction(tr("Open link"), this, SLOT(openLink()));
     menuBar()->addAction(tr("Full"), this, SLOT(openBrowser()));
-    connect(ui->m_thumbnailButton, SIGNAL(clicked()), this, SLOT(openLink()));
-    ui->m_thumbnailButton->setFlat(true);
+    connect(ui->textBrowser, SIGNAL(anchorClicked(QUrl)), this, SLOT(anchorClicked(QUrl)));
+    m_web = new WebPreview(this);
 
+    ui->textBrowser->setOpenLinks(false);
 }
 
 CommentView::~CommentView()
@@ -41,12 +45,31 @@ void CommentView::openLink()
 
 }
 
+namespace {
+
+QString makeAnchorText(const QString& url)
+{
+    return QString("<h2><a href=\"show\">%1</a></h2>").arg(url);
+}
+
+}
+
 void CommentView::setEntry(const RedditEntry &e)
 {
     m_entry = e;    
     m_ses->fetchComments(e.permalink);
     setWindowTitle(e.desc);
     PlatUtil::toggleBusy(this, true);
+
+    // bah, we don't want thumbnails anymore - just hit preview directly
+    // if we have direct image link
+
+    QString suffix = m_entry.url.right(3).toLower();
+    if (m_entry.thumbnail.length() || suffix == "jpg" || suffix == "png" || suffix == "gif") {
+        m_web->show();
+    }
+
+    /*
     if (m_entry.thumbnail.length()) {
         QNetworkRequest req(m_entry.thumbnail);
         QNetworkReply* reply = m_ses->m_net->get(req);
@@ -55,6 +78,10 @@ void CommentView::setEntry(const RedditEntry &e)
     } else {
         ui->m_thumbnailButton->setVisible(false);
     }
+    */
+    ui->textBrowser->setHtml(makeAnchorText(m_entry.url));
+    m_web->showUrl(m_entry.url);
+    m_web->setWindowTitle(m_entry.desc);
 
 }
 
@@ -75,11 +102,15 @@ void CommentView::populate()
     PlatUtil::toggleBusy(this, false);
     ui->textBrowser->clear();
 
+    if (m_ses->comments().length() < 3) {
+        m_web->show();
+    }
     QString coms = m_ses->comments().join("<hr/>");
-    QString all = "<p>"+coms+ "</p>";
+    QString all = QString("%1<p>%2</p>").arg(makeAnchorText(m_entry.url)).arg(coms);
     ui->textBrowser->setHtml(all);
 }
 
+/*
 void CommentView::thumbnailFetched()
 {
     QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
@@ -95,3 +126,10 @@ void CommentView::thumbnailFetched()
     reply->deleteLater();
 
 }
+
+*/
+void CommentView::anchorClicked(const QUrl &url)
+{
+    if (url.toString()  == "show")
+        m_web->show();
+}
