@@ -5,7 +5,9 @@
 
 class RedditSession;
 class RedditEntry;
+class WebPreview;
 
+class QUrl;
 #include "redditsession.h"
 namespace Ui {
     class CommentView;
@@ -25,13 +27,14 @@ protected:
 private slots:
     void populate();
     void openBrowser();
-    void thumbnailFetched();
     void openLink();
+    void anchorClicked(const QUrl&);
 private:
     Ui::CommentView *ui;
     RedditEntry m_entry;
 
     RedditSession* m_ses;
+    WebPreview* m_web;
 };
 
 #endif // COMMENTVIEW_H
