@@ -54,7 +54,7 @@ void MainWindow::populate()
     ui->listWidget->clear();
     for (int i=0; i < ents.count(); ++i) {;
         const RedditEntry& e = ents[i];
-        QString desc = e.desc;
+        QString desc = QString("%1 [%2]").arg(e.desc).arg(e.score);
 
         QListWidgetItem* it = new QListWidgetItem(desc);
 
