@@ -72,12 +72,14 @@ void RedditSession::linksFetched()
         QString url = v.property("url").toString();
         QString title = v.property("title").toString();        
         QString tnail = v.property("thumbnail").toString();
+        int score = v.property("score").toInt32();
         //qDebug() << v.toString() << title << " U " << url << " TN " << tnail;
         RedditEntry e;
         e.desc = title;
         e.url = url;
         e.permalink = v.property("permalink").toString();
         e.thumbnail = tnail;
+        e.score = score;
 
         m_ents.append(e);
     }
